/************************************************************************************
managementofareamapirs
Copyright (c) 2010, International Rescue System Institute
All rights reserved.

Contact us if you use this software for sell.
If you use this software not for sell, you can use this software under BSD license.
See the files LICENSE.TXT and LICENSE-BSD.TXT for more details.                     
************************************************************************************/

//***************************************************************************************//
//* TestInput.cpp							     2009.11.06 *//
//*											*//
//* Test Input RTMプログラム [Ver.0.1.0]						*//
//***************************************************************************************//


// -*- C++ -*-
/*!
 * @file  TestInput.cpp
 * @brief Test Input for Management of Area Map Module
 * $Date$
 *
 * $Id$
 */

#include "TestInput.h"

// Module specification
// <rtc-template block="module_spec">
static const char* testinput_spec[] =
  {
    "implementation_id", "TestInput",
    "type_name",         "TestInput",
    "description",       "Test Input for Management of Area Map Module",
    "version",           "0.1.0",
    "vendor",            "IRS",
    "category",          "Map",
    "activity_type",     "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    "conf.default.01_trigger", "1",
    "conf.default.02_mode", "1",
    "conf.default.03_location", "virtual_space",
    "conf.default.04_mapset", "irs",
    "conf.default.05_type", "landmark",
    "conf.default.06_originx", "-1000",
    "conf.default.07_originy", "-1000",
    "conf.default.08_sizex", "3000",
    "conf.default.09_sizey", "2000",

    ""
  };
// </rtc-template>

TestInput::TestInput(RTC::Manager* manager)
  : RTC::DataFlowComponentBase(manager),
    // <rtc-template block="initializer">
    m_MapOrderOut("MapOrder", m_MapOrder),
    
    // </rtc-template>
	dummy(0)
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  
  // Set OutPort buffer
  registerOutPort("MapOrder", m_MapOrderOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

}

TestInput::~TestInput()
{
}


RTC::ReturnCode_t TestInput::onInitialize()
{
	// <rtc-template block="bind_config">
	// Bind variables and configuration variable
	bindParameter("01_trigger", m_01_trigger, "1");
	bindParameter("02_mode", m_02_mode, "0");
	bindParameter("03_location", m_03_location, "kobe_green_space_park");
	bindParameter("04_mapset", m_04_mapset, "irs");
	bindParameter("05_type", m_05_type, "hazard");
	bindParameter("06_originx", m_06_originx, "-70000");
	bindParameter("07_originy", m_07_originy, "-100000");
	bindParameter("08_sizex", m_08_sizex, "340000");
	bindParameter("09_sizey", m_09_sizey, "160000");

	// </rtc-template>


	//-- [初期化] ---------------------------------------------------------------------------//

	m_MapOrder.location.length(DATASIZE);								// メモリ確保 [location]
	m_MapOrder.mapset.length(DATASIZE);								// メモリ確保 [mapset]
	m_MapOrder.type.length(DATASIZE);								// メモリ確保 [type]

	//---------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}



/*
RTC::ReturnCode_t TestInput::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t TestInput::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t TestInput::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

RTC::ReturnCode_t TestInput::onActivated(RTC::UniqueId ec_id)
{


	//-- [コンフィギュレーション読み込み] ---------------------------------------------------//

	trigger  = m_01_trigger;									// データ格納 [動作トリガー]
	mode     = m_02_mode;										// データ格納 [アクセスモード]
	strcpy(location, m_03_location.c_str());							// データ格納 [地域名]
	strcpy(mapset  , m_04_mapset.c_str());								// データ格納 [利用者マップセット名]
	strcpy(type    , m_05_type.c_str());								// データ格納 [データタイプ]
	origin_x = m_06_originx;									// データ格納 [対象原点x座標]
	origin_y = m_07_originy;									// データ格納 [対象原点y座標]
	size_x   = m_08_sizex;										// データ格納 [対象範囲x座標]
	size_y   = m_09_sizey;										// データ格納 [対象範囲y座標]

	//---------------------------------------------------------------------------------------//


	//-- [デバッグconfiguration] ------------------------------------------------------------//

	#ifndef DEBUG_CONFIGURATION									// デバッグ表示開始

	printf("\n[configuration]\n");									// label
	printf("01_trigger  = %d\n", trigger);								// trigger
	printf("02_mode     = %d\n", mode);								// mode
	printf("03_location = %s\n", location);								// location
	printf("04_mapset   = %s\n", mapset);								// mapset
	printf("05_type     = %s\n", type);								// type
	printf("06_originx  = %ld\n", origin_x);							// origin_x
	printf("07_originy  = %ld\n", origin_y);							// origin_y
	printf("08_sizex    = %ld\n", size_x);								// size_x
	printf("09_sizey    = %ld\n\n", size_y);							// size_y
	fflush(stdout);											// バッファフラッシュ [printf表示用]

	#endif												// デバッグ表示終了

	//---------------------------------------------------------------------------------------//


	//-- [タイムスタンプ格納] ---------------------------------------------------------------//

	timestamp = gettimeofday_sec();									// タイムスタンプ格納
	sec  = (unsigned long int)timestamp;								// タイムスタンプ格納 [sec]
	nsec = (unsigned long int)(fmod(timestamp, 1) * 1000000);					// タイムスタンプ格納 [nsec]

	//---------------------------------------------------------------------------------------//


	//-- [データ出力] -----------------------------------------------------------------------//

	m_MapOrder.tm.sec   = sec;									// タイムスタンプ格納 [sec]
	m_MapOrder.tm.nsec  = nsec;									// タイムスタンプ格納 [nsec]
	m_MapOrder.trigger  = trigger;									// 動作トリガー格納
	m_MapOrder.mode     = mode;									// アクセスモード格納
	for(i = 0; i <= (int)strlen(location); i++) m_MapOrder.location[i] = location[i];		// 地域名格納
	for(i = 0; i <= (int)strlen(mapset);   i++) m_MapOrder.mapset[i]   = mapset[i];			// 利用者マップセット名格納
	for(i = 0; i <= (int)strlen(type);     i++) m_MapOrder.type[i]     = type[i];			// データタイプ格納
	m_MapOrder.origin_x = origin_x;									// 対象原点x座標格納
	m_MapOrder.origin_y = origin_y;									// 対象原点y座標格納
	m_MapOrder.size_x   = size_x;									// 対象範囲x座標格納
	m_MapOrder.size_y   = size_y;									// 対象範囲y座標格納
	m_MapOrderOut.write();										// データ出力

	//---------------------------------------------------------------------------------------//


	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

RTC::ReturnCode_t TestInput::onDeactivated(RTC::UniqueId ec_id)
{

	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

RTC::ReturnCode_t TestInput::onExecute(RTC::UniqueId ec_id)
{

	return RTC::RTC_OK;										// 戻り値 [正常終了]

}

/*
RTC::ReturnCode_t TestInput::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t TestInput::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t TestInput::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t TestInput::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t TestInput::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{

  void TestInputInit(RTC::Manager* manager)
  {
    RTC::Properties profile(testinput_spec);
    manager->registerFactory(profile,
                             RTC::Create<TestInput>,
                             RTC::Delete<TestInput>);
  }

};


